@@ -3,8 +3,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef INCIDENCEEDITOR_FREEBUSYURLDIALOG_H
-#define INCIDENCEEDITOR_FREEBUSYURLDIALOG_H
+#pragma once
 
 #include "attendeedata.h"
 
@@ -40,9 +39,7 @@ public:
     void saveConfig();
 
 private:
-    KLineEdit *mUrlEdit = nullptr;
+    KLineEdit *const mUrlEdit;
     AttendeeData::Ptr mAttendee;
 };
 }
-
-#endif
