@@ -7,17 +7,14 @@
 
 #include "incidencecategories.h"
 
-#include "editorconfig.h"
-
 #include "incidenceeditor_debug.h"
 #include "ui_dialogdesktop.h"
 
-#include <CalendarSupport/Utils>
-
-#include <TagAttribute>
-#include <TagCreateJob>
-#include <TagFetchJob>
-#include <TagFetchScope>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/TagAttribute>
+#include <Akonadi/TagCreateJob>
+#include <Akonadi/TagFetchJob>
+#include <Akonadi/TagFetchScope>
 
 using namespace IncidenceEditorNG;
 
@@ -45,7 +42,7 @@ void IncidenceCategories::load(const KCalendarCore::Incidence::Ptr &incidence)
 
 void IncidenceCategories::load(const Akonadi::Item &item)
 {
-    mLoadedIncidence = CalendarSupport::incidence(item);
+    mLoadedIncidence = Akonadi::CalendarUtils::incidence(item);
     mDirty = false;
     mWasDirty = false;
 
@@ -128,7 +125,7 @@ void IncidenceCategories::onMissingTagCreated(KJob *job)
     auto createJob = static_cast<Akonadi::TagCreateJob *>(job);
     int count = mMissingCategories.removeAll(createJob->tag().name());
 
-    auto selectedTags {mUi->mTagWidget->selection()};
+    auto selectedTags{mUi->mTagWidget->selection()};
     selectedTags += createJob->tag();
 
     // If the created tag was one of the instance's missing categories,
