@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCECATEGORIES_H
-#define INCIDENCEEDITOR_INCIDENCECATEGORIES_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
@@ -24,6 +23,7 @@ public:
     explicit IncidenceCategories(Ui::EventOrTodoDesktop *ui);
 
     void load(const KCalendarCore::Incidence::Ptr &incidence) override;
+    void load(const Akonadi::Item &item) override;
     void save(const KCalendarCore::Incidence::Ptr &incidence) override;
     void save(Akonadi::Item &item) override;
 
@@ -39,10 +39,9 @@ private:
     void createMissingCategories();
 
     void onSelectionChanged(const Akonadi::Tag::List &);
-    void onTagsFetched(KJob *);
     void onMissingTagCreated(KJob *);
 
-    Ui::EventOrTodoDesktop *mUi = nullptr;
+    Ui::EventOrTodoDesktop *const mUi;
 
     /**
      * List of categories for which no tag might exist.
@@ -56,5 +55,3 @@ private:
     bool mDirty = false;
 };
 }
-
-#endif
