@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEWHATWHERE_H
-#define INCIDENCEEDITOR_INCIDENCEWHATWHERE_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
@@ -42,5 +41,3 @@ private:
     Ui::EventOrTodoDesktop *const mUi;
 };
 } // IncidenceEditorNG
-
-#endif
